[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Build Status](https://semaphoreci.com/api/v1/thr3742/r3d3/branches/master/badge.svg)](https://semaphoreci.com/thr3742/r3d3)

# r3d3
ML Experiment helpers
